@@ -3,7 +3,7 @@ import uuid
 from pathlib import Path
 from string import Formatter
 from types import ModuleType
-from typing import Dict, Set, Union
+from typing import Any, Dict, Set, Union
 
 import yaml
 from deprecated import deprecated
@@ -35,6 +35,7 @@ class ConfiguratorSingleton(type):
 
 
 class Configurator(ConfiguratorCli, metaclass=ConfiguratorSingleton):
+    _DEFAULT = object()
     _unique_id: str
     _raw_resource_details: TcDetails
     _is_debug: bool
@@ -62,6 +63,12 @@ class Configurator(ConfiguratorCli, metaclass=ConfiguratorSingleton):
         self.table_details = dict()
         self._set_extras()
 
+    def verify_consistency(self):
+        """This method will re-build the table details. This requires that all
+        internally recursive references can be resolved."""
+        self.table_details = dict()
+        return self.get_all_details()
+
     ############################################
     # the core logic of this class is contained
     # in the following methods
@@ -224,7 +231,10 @@ class Configurator(ConfiguratorCli, metaclass=ConfiguratorSingleton):
         # exception for any missing key, which will give a meaningful error to the user.
         return raw_string.format(**replacements)
 
-    def add_resource_path(self, resource_path: Union[str, ModuleType]) -> None:
+    def add_resource_path(
+        self, resource_path: Union[str, ModuleType], consistency_check=True
+    ) -> None:
+        self.table_details = dict()
         backup_details = self._raw_resource_details.copy()
         try:
             for file_name in importlib.resources.contents(resource_path):
@@ -242,19 +252,26 @@ class Configurator(ConfiguratorCli, metaclass=ConfiguratorSingleton):
                         for key, value in update.items():
                             # we now support all bare value types in yaml.
                             # no further checking
-                            self._raw_resource_details[key] = value
+                            self.register(key, value)
 
             # try re-building all details
-            self.table_details = dict()
-            self.get_all_details()
+            if consistency_check:
+                self.verify_consistency()
         except:  # noqa: E722  we re-raise the exception, so bare except is ok.
             # this piece makes it so that the Configurator can still be used
             # if any exception raised by the above code is caught.
             self._raw_resource_details = backup_details
             raise
 
-    def add_sql_resource_path(self, resource_path: Union[str, ModuleType]) -> None:
-        self._raw_resource_details.update(_parse_sql_to_config(resource_path))
+    def add_sql_resource_path(
+        self, resource_path: Union[str, ModuleType], consistency_check=True
+    ) -> None:
+        self.table_details = dict()
+        for key, value in _parse_sql_to_config(resource_path).items():
+            self.register(key, value)
+
+        if consistency_check:
+            self.verify_consistency()
 
     def key_of(self, attribute: str, value: str) -> str:
         """Obtain the key of the first registered item that has a given attribute
@@ -324,8 +341,18 @@ class Configurator(ConfiguratorCli, metaclass=ConfiguratorSingleton):
     def register(self, key: str, value: TcValue) -> str:
         """
         Register a new item and return its key.
+        If both the new and old items are dictionaries, their contents are merged.
+        Supply value=None to clear a key.
         """
-        self._raw_resource_details[key] = value
+        if value is None:
+            self._raw_resource_details.pop(key, None)
+        elif isinstance(value, dict) and isinstance(
+            self._raw_resource_details.get(key), dict
+        ):
+            # if both are dicts, update the contents.
+            self._raw_resource_details[key].update(value)
+        else:
+            self._raw_resource_details[key] = value
         self.table_details = dict()
         return key
 
@@ -381,8 +408,18 @@ class Configurator(ConfiguratorCli, metaclass=ConfiguratorSingleton):
         """
         return self.get(table_id, "path")
 
-    def get(self, table_id: str, property: str = "") -> str:
-        return self._get_item_property(table_id, property)
+    def get(self, table_id: str, property: str = "", default: Any = _DEFAULT):
+        """return the property of the table_id.
+        To get raw strings, specify no property.
+        If default is set, it is returned instead of raising in case of missing keys.
+        Return value will be whatever was registered under the given property."""
+        try:
+            return self._get_item_property(table_id, property)
+        except NoSuchValueException:
+            if default is self._DEFAULT:
+                raise
+            else:
+                return default
 
     def get_all_details(self):
         """
