@@ -13,7 +13,7 @@ class Readable(Protocol):
 class SimpleExtractor(Extractor):
     """This extractor will extract from any object that has a .read() method."""
 
-    def __init__(self, handle: Readable, dataset_key: str):
+    def __init__(self, handle: Readable, dataset_key: str = None):
         super().__init__(dataset_key=dataset_key)
         self.handle = handle
 
